import request from '@/utils/request'

// 查询特种设备检验记录列表
export function listCheck(query) {
  return request({
    url: '/sems/check/list',
    method: 'get',
    params: query
  })
}

// 查询特种设备检验记录详细
export function getCheck(id) {
  return request({
    url: '/sems/check/' + id,
    method: 'get'
  })
}

// 新增特种设备检验记录
export function addCheck(data) {
  return request({
    url: '/sems/check',
    method: 'post',
    data: data
  })
}

// 修改特种设备检验记录
export function updateCheck(data) {
  return request({
    url: '/sems/check',
    method: 'put',
    data: data
  })
}

// 删除特种设备检验记录
export function delCheck(id) {
  return request({
    url: '/sems/check/' + id,
    method: 'delete'
  })
}

// 导出特种设备检验记录
export function exportCheck(query) {
  return request({
    url: '/sems/check/export',
    method: 'get',
    params: query
  })
}
